@@ -175,7 +175,12 @@ impl PanelState for BrowserState {
     }
 
     fn selection(&self) -> Option<Selection<'_>> {
-        Some(self.displayed_tree().selected_line().as_selection())
+        let tree = self.displayed_tree();
+        let mut selection = tree.selected_line().as_selection();
+        selection.line = tree.options.pattern.pattern
+            .get_match_line_count(&selection.path)
+            .unwrap_or(0);
+        Some(selection)
     }
 
     fn tree_options(&self) -> TreeOptions {
@@ -390,14 +395,6 @@ impl PanelState for BrowserState {
                 }
             }
             Internal::parent => self.go_to_parent(screen, con, bang),
-            Internal::print_path => {
-                let path = &self.displayed_tree().selected_line().target();
-                print::print_path(path, con)?
-            }
-            Internal::print_relative_path => {
-                let path = &self.displayed_tree().selected_line().target();
-                print::print_relative_path(path, con)?
-            }
             Internal::print_tree => {
                 print::print_tree(&self.displayed_tree(), cc.app.screen, &cc.app.panel_skin, con)?
             }
