@@ -72,6 +72,12 @@ impl FuzzyPattern {
         }
     }
 
+    /// an "empty" pattern is one which accepts everything because
+    /// it has no discriminant
+    pub fn is_empty(&self) -> bool {
+        self.chars.is_empty()
+    }
+
     fn tight_match_from_index(
         &self,
         cand_chars: &CandChars,
@@ -186,8 +192,7 @@ impl FuzzyPattern {
         best_match
     }
 
-    /// compute the score of the best match, in a way mostly similar to `find` but
-    /// faster by not storing match positions
+    /// compute the score of the best match
     pub fn score_of(&self, candidate: &str) -> Option<i32> {
         self.find(candidate)
             .map(|nm| nm.score)
